@@ -24,7 +24,7 @@
   '("a4paper" "a5paper" "b5paper" "letterpaper" "legalpaper" "executivepaper"
     "landscape" "10pt" "11pt" "12pt" "oneside" "twoside" "draft" "final"
     "titlepage" "notitlepage" "onecolumn" "twocolumn" "leqno" "fleqn" "openbib")
-  "Package options for the article class.")
+  "Class options for the article class.")
 
 (TeX-add-style-hook
  "article"
