@@ -1,4 +1,4 @@
-;;; bicaption.el --- AUCTeX style for `bicaption.sty' (v1.1-158)  -*- lexical-binding: t; -*-
+;;; bicaption.el --- AUCTeX style for `bicaption.sty' (v1.6)  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2016--2023 Free Software Foundation, Inc.
 
@@ -10,24 +10,22 @@
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation; either version 3, or (at your option) any
+;; later version.
 
-;; AUCTeX is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; AUCTeX is distributed in the hope that it will be useful, but WITHOUT
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-;; 02110-1301, USA.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
-;; This file adds support for `bicaption.sty' (v1.1-158) from
-;; 2016/03/27.  `bicaption.sty' is part of TeXLive.
+;; This file adds support for `bicaption.sty' (v1.6) from
+;; 2023/07/10.  `bicaption.sty' is part of TeXLive.
 
 ;; If things do not work or when in doubt, press `C-c C-n'.  Comments
 ;; for improvement are welcome.
@@ -139,22 +137,6 @@ arguments."
       (indent-according-to-mode)
       (end-of-line))))
 
-(defun LaTeX-arg-bicaption-captionsetup (optional)
-  "Query for 2 arguments for \"\\captionsetup\" with bicaption.sty loaded.
-When OPTIONAL is non-nil, include both as optional arguments in
-square brackets."
-  (let* ((flttype (completing-read (TeX-argument-prompt optional nil "Float type")
-                                  LaTeX-caption-supported-float-types))
-         (biflt (if (and (not (or (string= flttype "bi")
-                                  (string= flttype "bi-first")
-                                  (string= flttype "bi-second")))
-                         flttype (not (string= flttype "")))
-                    (completing-read (TeX-argument-prompt optional nil "Bicaption type")
-                                     '("bi" "bi-first" "bi-second"))
-                  "")))
-    (TeX-argument-insert flttype optional)
-    (TeX-argument-insert biflt optional)))
-
 (TeX-add-style-hook
  "bicaption"
  (lambda ()
@@ -164,6 +146,13 @@ square brackets."
 
    ;; Macros
    (TeX-add-symbols
+    '("bicaptionsetup"
+      [TeX-arg-completing-read LaTeX-caption-supported-float-types
+                               "Float type"]
+      (TeX-arg-key-val (LaTeX-caption-key-val-options)
+                       "First language")
+      (TeX-arg-key-val (LaTeX-caption-key-val-options)
+                       "Second language"))
     '("bicaption"        (LaTeX-arg-bicaption-bicaption))
     '("bicaption*"       (LaTeX-arg-bicaption-bicaption  nil    t))
     '("bicaptionbox"     (LaTeX-arg-bicaption-bicaption  nil   nil  t   t) t)
@@ -175,7 +164,8 @@ square brackets."
 
    ;; \bi(sub)?caption(box)? macros should get their own lines
    (LaTeX-paragraph-commands-add-locally '("bicaption"    "bicaptionbox"
-                                           "bisubcaption" "bisubcaptionbox"))
+                                           "bisubcaption" "bisubcaptionbox"
+                                           "bicaptionsetup"))
 
    ;; Fontification
    (when (and (featurep 'font-latex)
@@ -184,7 +174,9 @@ square brackets."
                                 ("bicaptionbox"    "*[{[{[[")
                                 ("bisubcaption"    "*[{[{")
                                 ("bisubcaptionbox" "*[{[{[["))
-                              'textual)))
+                              'textual)
+     (font-latex-add-keywords '(("bicaptionsetup"  "[{{"))
+                              'function)))
  TeX-dialect)
 
 (defun LaTeX-bicaption-package-options-list ()
