@@ -1,4 +1,4 @@
-;;; minted.el --- AUCTeX style for `minted.sty' (v2.9)  -*- lexical-binding: t; -*-
+;;; minted.el --- AUCTeX style for `minted.sty' (v3.2.0)  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2014--2024 Free Software Foundation, Inc.
 
@@ -24,7 +24,7 @@
 
 ;;; Commentary:
 
-;; This file adds support for `minted.sty' (v2.9) from 2023/12/18.
+;; This file adds support for `minted.sty' (v3.2.0) from 2024/10/29.
 
 ;;; Code:
 
@@ -51,32 +51,35 @@
   '(("autogobble" ("true" "false"))
     ("baselinestretch" ("auto"))
     ("beameroverlays" ("true" "false"))
+    ("bgcolorpadding" ("none"))
+    ("bgcolorvphantom")
     ("breakafter")
     ("breakafterinrun" ("true" "false"))
-    ("breakaftersymbolpre")
     ("breakaftersymbolpost")
+    ("breakaftersymbolpre")
     ("breakanywhere" ("true" "false"))
-    ("breakanywheresymbolpre")
+    ("breakanywhereinlinestretch")
     ("breakanywheresymbolpost")
+    ("breakanywheresymbolpre")
     ("breakautoindent" ("true" "false"))
     ("breakbefore")
     ("breakbeforeinrun" ("true" "false"))
-    ("breakbeforesymbolpre")
     ("breakbeforesymbolpost")
+    ("breakbeforesymbolpre")
     ("breakbytoken" ("true" "false"))
     ("breakbytokenanywhere" ("true" "false"))
     ("breakindent")
     ("breakindentnchars")
     ("breaklines" ("true" "false"))
     ("breaksymbol")
-    ("breaksymbolleft")
-    ("breaksymbolright")
     ("breaksymbolindent")
     ("breaksymbolindentnchars")
     ("breaksymbolindentleft")
     ("breaksymbolindentleftnchars")
     ("breaksymbolindentright")
-    ("breaksymbolseprightnchars")
+    ("breaksymbolindentrightnchars")
+    ("breaksymbolleft")
+    ("breaksymbolright")
     ("breaksymbolsep")
     ("breaksymbolsepnchars")
     ("breaksymbolsepleft")
@@ -87,37 +90,57 @@
     ("codetagify")
     ("curlyquotes" ("true" "false"))
     ("encoding")
+    ("envname" ("Verbatim" "VerbEnv"))
     ("escapeinside")
+    ("extrakeywords")
+    ("extrakeywordsconstant")
+    ("extrakeywordsdeclaration")
+    ("extrakeywordsnamespace")
+    ("extrakeywordspseudo")
+    ("extrakeywordsreserved")
+    ("extrakeywordstype")
     ("firstline")
     ("firstnumber" ("auto" "last" "integer"))
     ("fontfamily" ("tt" "courier" "helvetica"))
     ("fontseries" ("auto"))
+    ("fontshape" ("auto"))
     ("fontsize" ("auto" "\\tiny" "\\large" "\\scriptsize" "\\Large"
                  "\\footnotesize" "\\LARGE" "\\small" "\\huge"
                  "\\normalsize" "\\Huge"))
-    ("fontshape" ("auto"))
     ("formatcom")
     ("frame" ("none" "leftline" "topline" "bottomline" "lines" "single"))
     ("framerule")
     ("framesep")
     ("funcnamehighlighting" ("true" "false"))
     ("gobble")
+    ("gobblefilter")
     ("highlightcolor")
     ("highlightlines")
     ("ignorelexererrors" ("true" "false"))
-    ("keywordcase" ("lower" "upper" "capitalize"))
+    ("keywordcase" ("lower" "upper" "capitalize" "none"))
     ("label")
     ("labelposition" ("none" "topline" "bottomline" "all"))
     ("lastline")
     ("linenos" ("true" "false"))
-    ("numberfirstline" ("true" "false"))
-    ("numbers" ("left" "right" "both" "none"))
+    ("listparameters")
+    ("literalenvname")
+    ("literatecomment")
     ("mathescape" ("true" "false"))
     ("numberblanklines" ("true" "false"))
+    ("numberfirstline" ("true" "false"))
+    ("numbers" ("left" "right" "both" "none"))
     ("numbersep")
     ("obeytabs" ("true" "false"))
     ("outencoding")
     ("python3" ("true" "false"))
+    ("rangeregex")
+    ("rangeregexmatchnumber")
+    ("rangeregexdotall" ("true" "false"))
+    ("rangeregexmultiline" ("true" "false"))
+    ("rangestartafterstring")
+    ("rangestartstring")
+    ("rangestopbeforestring")
+    ("rangestopstring")
     ("resetmargins" ("true" "false"))
     ("rulecolor")
     ("samepage" ("true" "false"))
@@ -126,6 +149,11 @@
     ("space")
     ("spacecolor")
     ("startinline" ("true" "false"))
+    ("stepnumber")
+    ("stepnumberfromfirst")
+    ("stepnumberoffsetvalues" ("true" "false"))
+    ("stripall" ("true" "false"))
+    ("stripnl" ("true" "false"))
     ;; FIXME: It would be nice to use the function
     ;; `LaTeX-minted-style-list' here, but with a file local var like:
     ;;     %%% TeX-command-extra-options: "-shell-escape"
@@ -145,11 +173,6 @@
               "solarized-dark" "solarized-light" "staroffice"
               "stata-dark" "stata-light" "tango" "trac"
               "vim" "vs" "xcode" "zenburn"))
-    ("stepnumber")
-    ("stepnumberfromfirst")
-    ("stepnumberoffsetvalues" ("true" "false"))
-    ("stripall" ("true" "false"))
-    ("stripnl" ("true" "false"))
     ("tab")
     ("tabcolor")
     ("tabsize")
@@ -169,7 +192,7 @@ prepends them to variable `LaTeX-minted-key-val-options'."
      (let* ((colorcmd (if (member "xcolor" TeX-active-styles)
                           #'LaTeX-xcolor-definecolor-list
                         #'LaTeX-color-definecolor-list))
-            (colors (mapcar #'car (funcall colorcmd)))
+            (colors (cons "none" (mapcar #'car (funcall colorcmd))))
             (keys '("bgcolor" "highlightcolor"
                     "rulecolor" "spacecolor" "tabcolor"))
             result)
@@ -243,22 +266,18 @@ Update the variable `LaTeX-minted-style-list' if still nil."
   "Process the parsed results from minted package."
   (dolist (mint (LaTeX-minted-newmint-list))
     (cond ((string= (nth 2 mint) "ed")
-           ;; \newminted{lang}{opts} => new langcode and langcode* envs.
-           ;; \newminted[envname]{lang}{opts} => new envname/envname* envs.
+           ;; \newminted{lang}{opts} => new langcode env.
+           ;; \newminted[envname]{lang}{opts} => new envname env.
            (let* ((env (if (string-empty-p (car mint))
                            (concat (cadr mint) "code")
-                         (car mint)))
-                  (env* (concat env "*")))
-             (LaTeX-add-environments (list env))
-             (LaTeX-add-environments (list env* #'LaTeX-env-args
-                                           '(TeX-arg-key-val
-                                             (LaTeX-minted-key-val-options))))
+                         (car mint))))
+             (LaTeX-add-environments
+              (list env
+                    #'LaTeX-env-args
+                    [TeX-arg-key-val (LaTeX-minted-key-val-options)]))
              (add-to-list 'LaTeX-indent-environment-list
                           `(,env current-indentation) t)
-             (add-to-list 'LaTeX-indent-environment-list
-                          `(,env* current-indentation) t)
-             (add-to-list 'LaTeX-verbatim-environments-local env)
-             (add-to-list 'LaTeX-verbatim-environments-local env*)))
+             (add-to-list 'LaTeX-verbatim-environments-local env)))
           ;; \newmintinline{foo}{opts} => \fooinline[key=vals]|code| or
           ;;                              \fooinline[key=vals]{code}
           ;; \newmintinline[macname]{foo}{opts} => \macname[key=vals]|code| or
@@ -355,8 +374,10 @@ a list of strings."
  "minted"
  (lambda ()
 
-   ;; Run the relevant style hooks:
-   (TeX-run-style-hooks "xcolor" "fvextra")
+   ;; Run the relevant style hooks and follow what minted.sty does:
+   (unless (member "color" (TeX-style-list))
+     (TeX-run-style-hooks "xcolor"))
+   (TeX-run-style-hooks "fvextra")
 
    ;; New symbols
    (TeX-add-symbols
@@ -465,18 +486,20 @@ a list of strings."
       ,(when (member "fontenc" (TeX-style-list))
          LaTeX-fontenc-package-options)))
    '(("chapter")
-     ("cache"            ("true" "false"))
+     ("cache"             ("true" "false"))
      ("cachedir")
-     ("finalizecache"    ("true" "false"))
-     ("frozencache"      ("true" "false"))
-     ("draft"            ("true" "false"))
-     ("final"            ("true" "false"))
-     ("inputlanglinenos" ("true" "false"))
-     ("kpsewhich"        ("true" "false"))
-     ("langlinenos"      ("true" "false"))
-     ("newfloat"         ("true" "false"))
-     ("outputdir")
-     ("section"))))
+     ("debug"             ("true" "false"))
+     ("frozencache"       ("true" "false"))
+     ("highlightmode"     ("fastfirst" "fast" "immediate"))
+     ;; The next 2 are now deprecated and may disappear sometimes:
+     ("inputlanglinenos"  ("true" "false"))
+     ("langlinenos"       ("true" "false"))
+     ("inputlexerlinenos" ("true" "false"))
+     ("lexerlinenos"      ("true" "false"))
+     ("newfloat"          ("true" "false"))
+     ("placeholder"       ("true" "false"))
+     ("section")
+     ("verbatim"          ("true" "false")))))
 
 (defun LaTeX-minted-package-options ()
   "Prompt for package options for the minted package."
