@@ -1,4 +1,4 @@
-;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v13.4.0)  -*- lexical-binding: t; -*-
+;;; simpleicons.el --- AUCTeX style for `simpleicons.sty' (v13.18.0)  -*- lexical-binding: t; -*-
 
 ;; Copyright (C) 2023--2024 Free Software Foundation, Inc.
 
@@ -24,8 +24,8 @@
 
 ;;; Commentary:
 
-;; This file adds support for `simpleicons.sty' (v13.4.0) from
-;; 2024/08/09.  `simpleicons.sty' is part of TeXLive.
+;; This file adds support for `simpleicons.sty' (v13.18.0) from
+;; 2024/11/29.  `simpleicons.sty' is part of TeXLive.
 
 ;;; Code:
 
@@ -44,6 +44,7 @@
     "1password"
     "2fas"
     "2k"
+    "30secondsofcode"
     "365datascience"
     "3m"
     "42"
@@ -68,6 +69,7 @@
     "activision"
     "activitypub"
     "actix"
+    "actualbudget"
     "acura"
     "adafruit"
     "adblock"
@@ -154,6 +156,7 @@
     "almalinux"
     "alpinedotjs"
     "alpinelinux"
+    "alternativeto"
     "alteryx"
     "altiumdesigner"
     "alwaysdata"
@@ -221,6 +224,7 @@
     "apachecloudstack"
     "apachecordova"
     "apachecouchdb"
+    "apachedolphinscheduler"
     "apachedruid"
     "apacheecharts"
     "apacheflink"
@@ -233,8 +237,10 @@
     "apachejmeter"
     "apachekafka"
     "apachekylin"
+    "apachelucene"
     "apachemaven"
     "apachenetbeanside"
+    "apachenifi"
     "apacheopenoffice"
     "apacheparquet"
     "apachepulsar"
@@ -301,6 +307,7 @@
     "asus"
     "atandt"
     "atari"
+    "atlasos"
     "atlassian"
     "auchan"
     "audacity"
@@ -360,6 +367,7 @@
     "baremetrics"
     "barmenia"
     "basecamp"
+    "baserow"
     "basicattentiontoken"
     "bastyon"
     "bat"
@@ -466,6 +474,7 @@
     "bugsnag"
     "buhl"
     "buildkite"
+    "builtbybit"
     "bukalapak"
     "bulma"
     "bun"
@@ -498,6 +507,7 @@
     "canva"
     "canvas"
     "capacitor"
+    "caprover"
     "cardano"
     "carlsberggroup"
     "carrd"
@@ -513,6 +523,7 @@
     "cbs"
     "ccleaner"
     "cdprojekt"
+    "ce"
     "celery"
     "celestron"
     "centos"
@@ -549,6 +560,7 @@
     "chupachups"
     "cilium"
     "cinema4d"
+    "cinnamon"
     "circle"
     "circleci"
     "circuitverse"
@@ -603,6 +615,7 @@
     "codechef"
     "codeclimate"
     "codecov"
+    "codecrafters"
     "codefactor"
     "codeforces"
     "codefresh"
@@ -648,6 +661,7 @@
     "confluence"
     "construct3"
     "consul"
+    "contabo"
     "contactlesspayment"
     "containerd"
     "contao"
@@ -671,6 +685,7 @@
     "countingworkspro"
     "coursera"
     "coveralls"
+    "coze"
     "cpanel"
     "cplusplus"
     "cplusplusbuilder"
@@ -693,6 +708,7 @@
     "cryengine"
     "cryptpad"
     "crystal"
+    "csdn"
     "css3"
     "cssdesignawards"
     "cssmodules"
@@ -742,6 +758,7 @@
     "dbt"
     "dcentertainment"
     "debian"
+    "debridlink"
     "decapcms"
     "decentraland"
     "dedge"
@@ -766,6 +783,7 @@
     "deutschebahn"
     "deutschebank"
     "deutschepost"
+    "deutschewelle"
     "devdotto"
     "devexpress"
     "deviantart"
@@ -811,6 +829,7 @@
     "doubanread"
     "dovecot"
     "dovetail"
+    "downdetector"
     "doxygen"
     "dpd"
     "dragonframe"
@@ -851,6 +870,7 @@
     "eclipsejetty"
     "eclipsemosquitto"
     "eclipsevertdotx"
+    "ecosia"
     "ecovacs"
     "edeka"
     "edgeimpulse"
@@ -875,6 +895,7 @@
     "element"
     "elementary"
     "elementor"
+    "elevenlabs"
     "eleventy"
     "elgato"
     "elixir"
@@ -956,6 +977,7 @@
     "fathom"
     "fauna"
     "favro"
+    "fcc"
     "fdroid"
     "feathub"
     "fedex"
@@ -1008,6 +1030,7 @@
     "flutter"
     "flux"
     "fluxus"
+    "flydotio"
     "flyway"
     "fmod"
     "fnac"
@@ -1047,6 +1070,7 @@
     "freelancermap"
     "freenas"
     "freepik"
+    "fresh"
     "frontendmentor"
     "frontify"
     "fsecure"
@@ -1221,6 +1245,7 @@
     "gtk"
     "guangzhoumetro"
     "guilded"
+    "guitarpro"
     "gulp"
     "gumroad"
     "gumtree"
@@ -1263,6 +1288,7 @@
     "hearthisdotat"
     "hedera"
     "helium"
+    "helix"
     "hellofresh"
     "hellyhansen"
     "helm"
@@ -1270,6 +1296,7 @@
     "helpscout"
     "hepsiemlak"
     "here"
+    "hermes"
     "heroku"
     "hetzner"
     "hevy"
@@ -1316,10 +1343,12 @@
     "huggingface"
     "hugo"
     "humblebundle"
+    "humhub"
     "hungryjacks"
     "husqvarna"
     "hyper"
     "hyperskill"
+    "hyperx"
     "hypothesis"
     "hyprland"
     "hyundai"
@@ -1362,6 +1391,7 @@
     "indiansuperleague"
     "indiehackers"
     "indigo"
+    "inductiveautomation"
     "inertia"
     "infiniti"
     "influxdb"
@@ -1418,6 +1448,7 @@
     "jamboard"
     "jameson"
     "jamstack"
+    "japanairlines"
     "jasmine"
     "javascript"
     "jbl"
@@ -1483,10 +1514,12 @@
     "kaufland"
     "kde"
     "kdenlive"
+    "kdeplasma"
     "kedro"
     "keenetic"
     "keepachangelog"
     "keepassxc"
+    "keeweb"
     "kentico"
     "keras"
     "keybase"
@@ -1548,6 +1581,7 @@
     "lamborghini"
     "landrover"
     "langchain"
+    "languagetool"
     "lapce"
     "laragon"
     "laravel"
@@ -1565,6 +1599,7 @@
     "leagueoflegends"
     "leanpub"
     "leetcode"
+    "lefthook"
     "legacygames"
     "leica"
     "lemmy"
@@ -1592,6 +1627,8 @@
     "libreofficeimpress"
     "libreofficemath"
     "libreofficewriter"
+    "libretranslate"
+    "libretube"
     "librewolf"
     "libuv"
     "lichess"
@@ -1649,6 +1686,7 @@
     "lubuntu"
     "lucia"
     "lucid"
+    "lucide"
     "ludwig"
     "lufthansa"
     "lumen"
@@ -1665,6 +1703,7 @@
     "magic"
     "magisk"
     "mahindra"
+    "mailboxdotorg"
     "mailchimp"
     "maildotcom"
     "maildotru"
@@ -1717,6 +1756,7 @@
     "mdx"
     "mediafire"
     "mediamarkt"
+    "mediapipe"
     "mediatek"
     "medibangpaint"
     "medium"
@@ -1755,6 +1795,7 @@
     "microstrategy"
     "midi"
     "migadu"
+    "mihoyo"
     "mikrotik"
     "milanote"
     "milvus"
@@ -1835,6 +1876,7 @@
     "namesilo"
     "namuwiki"
     "nano"
+    "nanostores"
     "nasa"
     "nationalgrid"
     "nationalrail"
@@ -1846,6 +1888,7 @@
     "nbc"
     "ndr"
     "near"
+    "nebula"
     "nec"
     "neo4j"
     "neovim"
@@ -1867,6 +1910,7 @@
     "newjapanprowrestling"
     "newrelic"
     "newyorktimes"
+    "nexon"
     "nextbilliondotai"
     "nextcloud"
     "nextdns"
@@ -1928,6 +1972,7 @@
     "nx"
     "nxp"
     "nzxt"
+    "o2"
     "observable"
     "obsidian"
     "obsstudio"
@@ -1939,12 +1984,15 @@
     "octoprint"
     "octopusdeploy"
     "oculus"
+    "odin"
     "odnoklassniki"
     "odoo"
     "odysee"
     "ohdear"
     "okcupid"
     "okta"
+    "okx"
+    "ollama"
     "oneplus"
     "onlyfans"
     "onlyoffice"
@@ -2183,9 +2231,11 @@
     "prevention"
     "prezi"
     "prime"
+    "primefaces"
     "primeng"
     "primereact"
     "primevideo"
+    "primevue"
     "printables"
     "prisma"
     "prismic"
@@ -2320,12 +2370,14 @@
     "redash"
     "redbubble"
     "redbull"
+    "redcandlegames"
     "reddit"
     "redhat"
     "redhatopenshift"
     "redis"
     "redmine"
     "redox"
+    "redragon"
     "redsys"
     "redux"
     "reduxsaga"
@@ -2379,6 +2431,7 @@
     "robinhood"
     "roblox"
     "robloxstudio"
+    "roboflow"
     "robotframework"
     "rocket"
     "rocketdotchat"
@@ -2488,6 +2541,7 @@
     "semrush"
     "semver"
     "sencha"
+    "sendgrid"
     "sennheiser"
     "sensu"
     "sentry"
@@ -2559,6 +2613,7 @@
     "smugmug"
     "snapchat"
     "snapcraft"
+    "snapdragon"
     "sncf"
     "snort"
     "snowflake"
@@ -2693,6 +2748,7 @@
     "subtitleedit"
     "subversion"
     "suckless"
+    "sui"
     "sumologic"
     "suno"
     "sunrise"
@@ -2708,8 +2764,10 @@
     "svg"
     "svgdotjs"
     "svgo"
+    "svgtrace"
     "swagger"
     "swarm"
+    "sway"
     "swc"
     "swift"
     "swiggy"
@@ -2743,6 +2801,7 @@
     "taobao"
     "tapas"
     "target"
+    "tarom"
     "task"
     "tasmota"
     "tata"
@@ -2779,10 +2838,12 @@
     "textpattern"
     "tga"
     "thangs"
+    "thanos"
     "thealgorithms"
     "theboringcompany"
     "theconversation"
     "thefinals"
+    "theguardian"
     "theirishtimes"
     "themighty"
     "themodelsresource"
@@ -2793,6 +2854,7 @@
     "thesoundsresource"
     "thespritersresource"
     "thewashingtonpost"
+    "theweatherchannel"
     "thingiverse"
     "thinkpad"
     "thirdweb"
@@ -2949,6 +3011,7 @@
     "upwork"
     "usps"
     "utorrent"
+    "uv"
     "v"
     "v2ex"
     "v8"
@@ -2977,6 +3040,7 @@
     "veritas"
     "verizon"
     "vespa"
+    "vestel"
     "vexxhost"
     "vfairs"
     "viadeo"
@@ -3016,6 +3080,7 @@
     "vorondesign"
     "vowpalwabbit"
     "vox"
+    "vrchat"
     "vsco"
     "vscodium"
     "vtex"
@@ -3128,11 +3193,13 @@
     "xiaohongshu"
     "xiaomi"
     "xing"
+    "xml"
     "xmpp"
     "xo"
     "xrp"
     "xsplit"
     "xstate"
+    "xubuntu"
     "yabai"
     "yale"
     "yamahacorporation"
@@ -3143,6 +3210,7 @@
     "ycombinator"
     "yelp"
     "yeti"
+    "yii"
     "yoast"
     "youtube"
     "youtubegaming"
