@@ -1,6 +1,6 @@
 ;;; thmtools.el --- AUCTeX style for `thmtools.sty' (v0.72)  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2018--2022 Free Software Foundation, Inc.
+;; Copyright (C) 2018--2023 Free Software Foundation, Inc.
 
 ;; Author: Arash Esbati <arash@gnu.org>
 ;; Maintainer: auctex-devel@gnu.org
@@ -10,19 +10,17 @@
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
-;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 3, or (at your option)
-;; any later version.
+;; under the terms of the GNU General Public License as published by the
+;; Free Software Foundation; either version 3, or (at your option) any
+;; later version.
 
-;; AUCTeX is distributed in the hope that it will be useful, but
-;; WITHOUT ANY WARRANTY; without even the implied warranty of
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-;; General Public License for more details.
+;; AUCTeX is distributed in the hope that it will be useful, but WITHOUT
+;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; for more details.
 
 ;; You should have received a copy of the GNU General Public License
-;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-;; 02110-1301, USA.
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 ;;; Commentary:
 
@@ -205,8 +203,8 @@ Select the content of the optional argument with a key:
 RET in order to leave it empty.")
          (choice (read-char-choice
                   (TeX-argument-prompt
-                   nil nil "Heading (h), Key=val (k), Empty (RET)")
-                  '(?h ?k)))
+                   nil nil "Heading (h), Key=val (k), Empty (RET), Help (C-h)")
+                  '(?h ?k ?\r)))
          (opthead (cond ((= choice ?h)
                          (TeX-read-string
                           (TeX-argument-prompt t nil "Heading")))
@@ -222,7 +220,11 @@ RET in order to leave it empty.")
                             ;; much easier for AUCTeX and RefTeX
                             ;; ("label")
                             ("listhack" ("true" "false")))))
-                        (t ""))))
+                        (t
+                         ;; Clear minibuffer and don't leave the ugly
+                         ;; ^M there and return an empty string:
+                         (message nil)
+                         ""))))
     (LaTeX-insert-environment environment
                               (when (and opthead
                                          (not (string= opthead "")))
